"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
const page_actions_1 = require("../../../page-actions");
describe('get elements with text', () => {
    let browser = undefined;
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should return an empty array when root elements is empty', async () => {
        // Given
        // When
        const result = await SUT.getHandlesWithText('foobar', []);
        // Then
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(0);
    });
    test('should return only one element', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-handles-with-text.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"]', page);
        const result = await SUT.getHandlesWithText('row2', rootElements);
        // Then
        expect(rootElements.length).toBe(3);
        expect(result.length).toBe(1);
        expect(await result[0].evaluate((node) => node.innerText)).toContain('row2');
    });
    test('should return only two elements', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-handles-with-text.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"]', page);
        const result = await SUT.getHandlesWithText('cell3', rootElements);
        // Then
        expect(rootElements.length).toBe(3);
        expect(result.length).toBe(2);
        expect(await result[0].evaluate((node) => node.innerText)).toContain('row2-cell2');
        expect(await result[1].evaluate((node) => node.innerText)).toContain('row3-cell2');
    });
    test('should return no elements when text is not found', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-handles-with-text.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"]', page);
        const result = await SUT.getHandlesWithText('foobar', rootElements);
        // Then
        expect(rootElements.length).toBe(3);
        expect(result.length).toBe(0);
    });
});
