"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
const page_actions_1 = require("../../../page-actions");
describe('get parents', () => {
    let browser = undefined;
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should return an empty array when root elements is empty', async () => {
        // Given
        // When
        const result = await SUT.getParentsOf([]);
        // Then
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(0);
    });
    test('should get parents', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-parent-of-handles.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"]', page);
        const result = await SUT.getParentsOf(rootElements);
        // Then
        expect(rootElements.length).toBe(3);
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(3);
        expect(await result[0].evaluate((node) => node.tagName)).toContain('TBODY');
        expect(await result[1].evaluate((node) => node.tagName)).toContain('TBODY');
        expect(await result[2].evaluate((node) => node.tagName)).toContain('TBODY');
    });
    test('should get parent', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-parent-of-handles.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('select[data-test-id="my-select2"]', page);
        const result = await SUT.getParentsOf(rootElements);
        // Then
        expect(rootElements.length).toBe(1);
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(1);
        expect(await result[0].evaluate((node) => node.tagName)).toContain('TD');
    });
    test('should return no elements when parent is not found', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-parent-of-handles.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('html', page);
        const result = await SUT.getParentsOf(rootElements);
        // Then
        expect(rootElements.length).toBe(1);
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(0);
    });
});
