"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
describe('handle has placeholder', () => {
    let browser = undefined;
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should return true when selector has placeholder', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'has-handle-placeholder.test.html')}`;
        await page.goto(url);
        const selector = '#with-placeholder';
        const handle = await page.$(selector);
        // When
        const result = await SUT.hasHandlePlaceholder(handle, 'type text here');
        // Then
        expect(handle).toBeDefined();
        expect(result).toBe(true);
    });
    test('should return false when selector has no placeholder', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'has-handle-placeholder.test.html')}`;
        await page.goto(url);
        const selector = '#with-no-placeholder';
        const handle = await page.$(selector);
        // When
        const result = await SUT.hasHandlePlaceholder(handle, 'foobar');
        // Then
        expect(handle).toBeDefined();
        expect(result).toBe(false);
    });
    test('should return false when placeholder does not match', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'has-handle-placeholder.test.html')}`;
        await page.goto(url);
        const selector = '#with-placeholder';
        const handle = await page.$(selector);
        // When
        const result = await SUT.hasHandlePlaceholder(handle, 'foobar');
        // Then
        expect(handle).toBeDefined();
        expect(result).toBe(false);
    });
});
