"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
const page_actions_1 = require("../../../page-actions");
describe('query selector all from handles', () => {
    let browser = undefined;
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should return an empty array when root elements is empty', async () => {
        // Given
        // When
        const result = await SUT.querySelectorAllFromHandles('foobar', []);
        // Then
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(0);
    });
    test('should return all found elements - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'query-selector-all-from-handles.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"]', page);
        const result = await SUT.querySelectorAllFromHandles('select[data-test-id="my-select"]', rootElements);
        // Then
        expect(result.length).toBe(3);
        expect(await result[0].evaluate((node) => node.value)).toBe('1');
        expect(await result[1].evaluate((node) => node.value)).toBe('2');
        expect(await result[2].evaluate((node) => node.value)).toBe('3');
    });
    test('should return no elements when child selector is not found - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'query-selector-all-from-handles.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"]', page);
        const result = await SUT.querySelectorAllFromHandles('foobar', rootElements);
        // Then
        expect(rootElements.length).toBe(3);
        expect(result.length).toBe(0);
    });
});
