"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
const dom_actions_1 = require("../../../dom-actions");
const paste_text_1 = require("../paste-text");
const utils_1 = require("../../../../utils");
describe('paste text', () => {
    let browser = undefined;
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should paste text in a content-editable element that do not have paste event handler - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        await (0, dom_actions_1.showMousePosition)(page);
        const url = `file:${path.join(__dirname, 'paste-text.test.html')}`;
        await page.goto(url);
        await (0, utils_1.sleep)(1000);
        const selector = '#target';
        await page.click(selector);
        const handle = await page.$(selector);
        // When
        await SUT.pasteText('foobar', page, {
            ...paste_text_1.defaultPasteTextOptions,
            handlePasteEvent: true,
        });
        // Then
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(await handle.evaluate((node) => node.innerHTML)).toBe('foobar');
    });
    test('should paste text in an input element that do not have paste event handler - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        await (0, dom_actions_1.showMousePosition)(page);
        const url = `file:${path.join(__dirname, 'paste-text.test.html')}`;
        await page.goto(url);
        await (0, utils_1.sleep)(1000);
        const selector = '#targetInput';
        await page.click(selector);
        const handle = await page.$(selector);
        // When
        await SUT.pasteText('foobar', page, {
            ...paste_text_1.defaultPasteTextOptions,
            handlePasteEvent: true,
        });
        // Then
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(await handle.evaluate((node) => node.value)).toBe('foobar');
    });
    test('should paste text in a content-editable element that have paste event handler - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        await (0, dom_actions_1.showMousePosition)(page);
        const url = `file:${path.join(__dirname, 'paste-text.test.html')}`;
        await page.goto(url);
        await (0, utils_1.sleep)(1000);
        const selector = '#emptyInput';
        await page.click(selector);
        // When
        await SUT.pasteText('foobar', page, paste_text_1.defaultPasteTextOptions);
        // Then
        const handle = await page.$(selector);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(await handle.evaluate((node) => node.value)).toBe('FOOBAR');
    });
    test('should paste text without clearing existing content in an input element that do not have paste event handler - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        await (0, dom_actions_1.showMousePosition)(page);
        const url = `file:${path.join(__dirname, 'paste-text.test.html')}`;
        await page.goto(url);
        await (0, utils_1.sleep)(1000);
        const selector = '#targetInput';
        await page.click(selector);
        const handle = await page.$(selector);
        // When
        await SUT.pasteText(' here', page, {
            ...paste_text_1.defaultPasteTextOptions,
            handlePasteEvent: true,
            clearExistingContent: false,
        });
        // Then
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(await handle.evaluate((node) => node.value)).toBe('paste your text here');
    });
    test('should paste text without clearing existing content in a content-editable element that do not have paste event handler - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        await (0, dom_actions_1.showMousePosition)(page);
        const url = `file:${path.join(__dirname, 'paste-text.test.html')}`;
        await page.goto(url);
        await (0, utils_1.sleep)(1000);
        const selector = '#target';
        await page.click(selector);
        const handle = await page.$(selector);
        // When
        await SUT.pasteText(' here', page, {
            ...paste_text_1.defaultPasteTextOptions,
            handlePasteEvent: true,
            clearExistingContent: false,
        });
        // Then
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(await handle.evaluate((node) => node.innerHTML)).toBe('paste your text here');
    });
});
