import { Frame, Page } from 'playwright';
export interface WindowState {
    /**
     * Interior height of the browser window in pixels,
     * including the height of the horizontal scroll bar, if present.
     *
     * @type {number}
     * @memberof WindowState
     */
    innerHeight: number;
    /**
     * Interior width of the browser window in pixels.
     * This includes the width of the vertical scroll bar,
     * if one is present.
     *
     * @type {number}
     * @memberof WindowState
     */
    innerWidth: number;
    /**
     * Tells if the browser window is very near to the screen size
     *
     * @type {boolean}
     * @memberof WindowState
     */
    isMaximized: boolean;
    /**
     * Width of the whole browser window,
     * including sidebar (if expanded),
     * window chrome and window resizing borders/handles
     *
     * @type {number}
     * @memberof WindowState
     */
    outerHeight: number;
    /**
     *
     *
     * @type {number}
     * @memberof WindowState
     */
    outerWidth: number;
    screen: {
        availWidth: number;
        availHeight: number;
    };
}
export declare function getWindowState(page: Page | Frame | undefined): Promise<WindowState>;
