"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const fs_1 = require("fs");
const playwright_1 = require("playwright");
const simple_fake_server_1 = require("simple-fake-server");
const SUT = tslib_1.__importStar(require("../index"));
const record_requests_to_1 = require("../../record-requests-to");
const utils_1 = require("../../../../utils");
const index_1 = require("../index");
describe('on request to respond from HAR files', () => {
    let browser = undefined;
    let fakeServer = undefined;
    beforeAll(() => {
        fakeServer = new simple_fake_server_1.FakeServer(1235);
        fakeServer.start();
        //The FakeServer now listens on http://localhost:1235
    });
    afterAll(() => {
        if (fakeServer) {
            fakeServer.stop();
        }
    });
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should mock response from HAR file', async () => {
        // Given
        browser = await playwright_1.chromium.launch({
            headless: true,
        });
        const context = await browser.newContext({ viewport: null });
        const page = await context.newPage();
        const responseBody = {
            prop1: 'foobar',
        };
        const mockResponseBody = {
            prop1: 'mock-foobar',
        };
        const harResponseBody = {
            prop1: 'mocked-prop1',
        };
        const responseHeaders = {
            'foo-header': 'bar',
        };
        fakeServer &&
            // prettier-ignore
            fakeServer.http
                .get()
                .to('/foobar')
                .willReturn(responseBody, 200, responseHeaders);
        const htmlContent = (0, fs_1.readFileSync)(`${path.join(__dirname, 'on-request-to-respond-from-har.test.html')}`);
        fakeServer &&
            // prettier-ignore
            fakeServer.http
                .get()
                .to('/app')
                .willReturn(htmlContent.toString(), 200);
        const requests = [];
        const takeAllPredicate = () => false;
        const callback = (request) => requests.push(request);
        await (0, record_requests_to_1.recordRequestsTo)('/foobar', takeAllPredicate, page, callback);
        const harFile = path.join(__dirname, 'on-request-to-respond-with.har');
        const harFiles = [harFile];
        const foundUrls = [];
        const notFoundUrls = [];
        const options = {
            ...index_1.defaultHarRequestResponseOptions,
            onHarEntryFound: (_foundEntry, requestedUrl, requestedMethod) => {
                foundUrls.push(`found entry for url : '${requestedMethod}' ${requestedUrl}`);
            },
            onHarEntryNotFound: (_allEntries, requestedUrl, requestedMethod) => {
                notFoundUrls.push(`not found entry for url :  '${requestedMethod}' ${requestedUrl}`);
            },
        };
        // When
        await SUT.onRequestToRespondFromHar('/foobar', harFiles, page, options);
        await page.goto('http://localhost:1235/app');
        await (0, utils_1.sleep)(3000);
        // Then
        expect(requests.length).toBe(1);
        const stringifiedRequest = await (0, utils_1.stringifyRequest)(requests[0]);
        const request = JSON.parse(stringifiedRequest);
        expect(request.url).toContain('?foo=bar');
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(request.response.status).toBe(200);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(request.response.payload).not.toMatchObject(responseBody);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(request.response.payload).not.toMatchObject(mockResponseBody);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(request.response.payload).toMatchObject(harResponseBody);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        expect(request.response.headers['foo-header']).toBe('har-bar');
    });
});
