"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recordFailedRequests = void 0;
const failedStatus = [500, 503, 400, 401, 403, 307];
async function recordFailedRequests(page, callback) {
    if (!page) {
        throw new Error(`Cannot record failed requests because no browser has been launched`);
    }
    page.on('requestfinished', async (request) => {
        const response = await request.response();
        if (response === null) {
            const typedRequest = request;
            callback(typedRequest);
            return;
        }
        const status = response.status();
        if (failedStatus.includes(status)) {
            const typedRequest = request;
            callback(typedRequest);
            return;
        }
    });
    page.on('requestfailed', (request) => {
        const typedRequest = request;
        callback(typedRequest);
        return;
    });
}
exports.recordFailedRequests = recordFailedRequests;
