"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
const dom_actions_1 = require("../../../dom-actions");
const handle_actions_1 = require("../../../handle-actions");
const hover_on_selector_1 = require("../../hover-on-selector");
const is_selector_visible_1 = require("../../is-selector-visible");
const utils_1 = require("../../../../utils");
describe('switch from selector to iframe', () => {
    let browser = undefined;
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    afterEach(async () => {
        if (browser) {
            await browser.close();
        }
    });
    test('should switch to iframe - chromium', async () => {
        // Given
        browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        await (0, dom_actions_1.showMousePosition)(page);
        const url = `file:${path.join(__dirname, 'switch-from-selector-to-iframe.test.html')}`;
        await page.goto(url);
        const frameSelector = 'iframe';
        const selector = '#inside-iframe';
        const options = {
            ...handle_actions_1.defaultSwitchToIframeOptions,
        };
        // When
        const frame = await SUT.switchFromSelectorToIframe(frameSelector, page, options);
        await (0, hover_on_selector_1.hoverOnSelector)(selector, frame, options);
        const isSelectorVisibleAfterScroll = await (0, is_selector_visible_1.isSelectorVisible)(selector, frame, utils_1.defaultWaitUntilOptions);
        // Then
        expect(frame).toBeDefined();
        expect(isSelectorVisibleAfterScroll).toBe(true);
        const mousePositionClientRectangle = await (0, dom_actions_1.getClientRectangleOf)('playwright-mouse-pointer', frame);
        const mouseX = mousePositionClientRectangle.left + mousePositionClientRectangle.width / 2;
        const mouseY = mousePositionClientRectangle.top + mousePositionClientRectangle.height / 2;
        const currentClientRectangle = await (0, dom_actions_1.getClientRectangleOf)(selector, frame);
        const expectedX = currentClientRectangle.left + currentClientRectangle.width / 2;
        const expectedY = currentClientRectangle.top + currentClientRectangle.height / 2;
        expect(Math.abs(mouseX - expectedX)).toBeLessThanOrEqual(1);
        expect(Math.abs(mouseY - expectedY)).toBeLessThanOrEqual(1);
    });
});
