import { Request } from 'playwright';
import { FluentMock, WithMocksOptions } from './with-mocks';
export interface OutdatedMock {
    url: string;
    mock: Partial<FluentMock>;
    actualResponse: string | unknown;
    mockedResponse: string | unknown;
}
/**
 * Get outdated mocks from the given unintercepted requests.
 * If a mock is found to be outdated and has provided a method to update its data source,
 * then the update method will be called, so that the mock can update itself the data source of the mocked response.
 * @export
 * @param {Partial<FluentMock>[]} mocks
 * @param {Request[]} requests
 * @param {Partial<WithMocksOptions>} options
 * @param {unknown} [sharedContext={}]
 * @returns {Promise<OutdatedMock[]>}
 */
export declare function getOutdatedMocks(mocks: Partial<FluentMock>[], requests: Request[], options: Partial<WithMocksOptions>, sharedContext?: unknown): Promise<OutdatedMock[]>;
