"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isSelectorObjectNotVisibleInViewport = void 0;
const utils_1 = require("../../../utils");
const handle_actions_1 = require("../../handle-actions");
async function isSelectorObjectNotVisibleInViewport(selector, page, options) {
    if (!page) {
        throw new Error(`Cannot get visibility status of '${selector.toString()}' because no browser has been launched`);
    }
    const isVisible = await (0, handle_actions_1.isHandleVisibleInViewport)(await selector.getHandle(), {
        verbose: options.verbose,
    });
    if (isVisible) {
        (0, utils_1.report)('waiting for the selector to disappear from the current viewport ...', options.verbose);
        await (0, utils_1.waitUntil)(() => selector.isNotVisibleInViewport(), `'${selector.toString()}' is visible in the current viewport.`, options);
    }
    const handle = await selector.getHandle();
    return await (0, handle_actions_1.isHandleNotVisibleInViewport)(handle, { verbose: options.verbose });
}
exports.isSelectorObjectNotVisibleInViewport = isSelectorObjectNotVisibleInViewport;
