"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isSelectorObjectNotVisible = void 0;
const utils_1 = require("../../../utils");
const handle_actions_1 = require("../../handle-actions");
async function isSelectorObjectNotVisible(selector, page, options) {
    if (!page) {
        throw new Error(`Cannot get visibility status of '${selector.toString()}' because no browser has been launched`);
    }
    const isVisible = await (0, handle_actions_1.isHandleVisible)(await selector.getHandle(), {
        verbose: options.verbose,
    });
    if (isVisible) {
        (0, utils_1.report)('waiting for the selector to disappear ...', options.verbose);
        await (0, utils_1.waitUntil)(() => selector.isNotVisible(), `'${selector.toString()}' is visible.`, options);
    }
    const handle = await selector.getHandle();
    return await (0, handle_actions_1.isHandleNotVisible)(handle, { verbose: options.verbose });
}
exports.isSelectorObjectNotVisible = isSelectorObjectNotVisible;
