"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorDoesExist = exports.doesExist = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function doesExist(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.selectorExists(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.selectorObjectExists(selector, page, waitOptions);
        return result;
    }
}
exports.doesExist = doesExist;
async function expectThatCssSelectorDoesExist(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => doesExist(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector}' was not found in DOM.`, waitOptions);
}
async function expectThatSelectorObjectDoesExist(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => doesExist(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector.toString()}' was not found in DOM.`, waitOptions);
}
async function expectThatSelectorDoesExist(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorDoesExist(selector, page, options);
    }
    return await expectThatSelectorObjectDoesExist(selector, page, options);
}
exports.expectThatSelectorDoesExist = expectThatSelectorDoesExist;
