"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorDoesNotExist = exports.doesNotExist = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function doesNotExist(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.selectorDoesNotExist(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.selectorObjectDoesNotExist(selector, page, waitOptions);
        return result;
    }
}
exports.doesNotExist = doesNotExist;
async function expectThatCssSelectorDoesNotExist(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => doesNotExist(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector}' was still found in DOM.`, waitOptions);
}
async function expectThatSelectorObjectDoesNotExist(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => doesNotExist(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector.toString()}' was still found in DOM.`, waitOptions);
}
async function expectThatSelectorDoesNotExist(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorDoesNotExist(selector, page, options);
    }
    return await expectThatSelectorObjectDoesNotExist(selector, page, options);
}
exports.expectThatSelectorDoesNotExist = expectThatSelectorDoesNotExist;
