"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorDoesNotHaveClass = exports.doesNotHaveClass = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function doesNotHaveClass(selector, expectedClass, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.hasNotSelectorClass(selector, expectedClass, page, waitOptions);
        return result;
    }
    {
        const result = await action.hasNotSelectorObjectClass(selector, expectedClass, page, waitOptions);
        return result;
    }
}
exports.doesNotHaveClass = doesNotHaveClass;
async function expectThatCssSelectorDoesNotHaveClass(selector, expectedClass, page, options) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => doesNotHaveClass(selector, expectedClass, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        const currentClassList = await action.getClassListOfSelector(selector, page, utils_1.noWaitNoThrowOptions);
        return `Selector '${selector}' has classes '${currentClassList}', but it should not have class '${expectedClass}'`;
    }, waitOptions);
}
async function expectThatSelectorObjectDoesNotHaveClass(selector, expectedClass, page, options) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => doesNotHaveClass(selector, expectedClass, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        const currentClassList = await selector.classList();
        return `'${selector.toString()}' has classes '${currentClassList}', but it should not have class '${expectedClass}'`;
    }, waitOptions);
}
async function expectThatSelectorDoesNotHaveClass(selector, expectedClass, page, options = fluent_api_1.defaultAssertOptions) {
    const assertOptions = {
        ...fluent_api_1.defaultAssertOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        return await expectThatCssSelectorDoesNotHaveClass(selector, expectedClass, page, assertOptions);
    }
    return await expectThatSelectorObjectDoesNotHaveClass(selector, expectedClass, page, assertOptions);
}
exports.expectThatSelectorDoesNotHaveClass = expectThatSelectorDoesNotHaveClass;
