"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorHasClass = exports.hasClass = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function hasClass(selector, expectedClass, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.hasSelectorClass(selector, expectedClass, page, waitOptions);
        return result;
    }
    {
        const result = await action.hasSelectorObjectClass(selector, expectedClass, page, waitOptions);
        return result;
    }
}
exports.hasClass = hasClass;
async function expectThatCssSelectorHasClass(selector, expectedClass, page, options) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => hasClass(selector, expectedClass, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        const currentClassList = await action.getClassListOfSelector(selector, page, utils_1.noWaitNoThrowOptions);
        if (Array.isArray(currentClassList) && currentClassList.length === 0) {
            return `Selector '${selector}' does not have class '${expectedClass}', because no class has been found on the selector`;
        }
        return `Selector '${selector}' does not have class '${expectedClass}', but instead has classes '${currentClassList}'`;
    }, waitOptions);
}
async function expectThatSelectorObjectHasClass(selector, expectedClass, page, options) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => hasClass(selector, expectedClass, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        const currentClassList = await selector.classList();
        if (Array.isArray(currentClassList) && currentClassList.length === 0) {
            return `'${selector.toString()}' does not have class '${expectedClass}', because no class has been found on the selector`;
        }
        return `'${selector.toString()}' does not have class '${expectedClass}', but instead has classes '${currentClassList}'`;
    }, waitOptions);
}
async function expectThatSelectorHasClass(selector, expectedClass, page, options = fluent_api_1.defaultAssertOptions) {
    const assertOptions = {
        ...fluent_api_1.defaultAssertOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        return await expectThatCssSelectorHasClass(selector, expectedClass, page, assertOptions);
    }
    return await expectThatSelectorObjectHasClass(selector, expectedClass, page, assertOptions);
}
exports.expectThatSelectorHasClass = expectThatSelectorHasClass;
