"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorHasFocus = exports.hasFocus = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function hasFocus(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.hasSelectorFocus(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.hasSelectorObjectFocus(selector, page, waitOptions);
        return result;
    }
}
exports.hasFocus = hasFocus;
async function expectThatCssSelectorHasFocus(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => hasFocus(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        return `Selector '${selector}' does not have the focus.`;
    }, waitOptions);
}
async function expectThatSelectorObjectHasFocus(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => hasFocus(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        return `Selector '${selector.toString()}' does not have the focus.`;
    }, waitOptions);
}
async function expectThatSelectorHasFocus(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorHasFocus(selector, page, options);
    }
    return await expectThatSelectorObjectHasFocus(selector, page, options);
}
exports.expectThatSelectorHasFocus = expectThatSelectorHasFocus;
