"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorHasText = exports.hasText = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function hasText(selector, expectedText, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.hasSelectorText(selector, expectedText, page, waitOptions);
        return result;
    }
    {
        const result = await action.hasSelectorObjectText(selector, expectedText, page, waitOptions);
        return result;
    }
}
exports.hasText = hasText;
async function expectThatCssSelectorHasText(selector, expectedText, page, options) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => hasText(selector, expectedText, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        const currentInnerText = await action.getInnerTextOfSelector(selector, page, utils_1.noWaitNoThrowOptions);
        return `Inner text of selector '${selector}' does not contain '${expectedText}', but instead it contains '${(0, utils_1.safeToString)(currentInnerText)}'`;
    }, waitOptions);
}
async function expectThatSelectorObjectHasText(selector, expectedText, page, options) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => hasText(selector, expectedText, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        const currentInnerText = await selector.innerText();
        return `Inner text of '${selector.toString()}' does not contain '${expectedText}', but instead it contains '${(0, utils_1.safeToString)(currentInnerText)}'`;
    }, waitOptions);
}
async function expectThatSelectorHasText(selector, expectedText, page, options = fluent_api_1.defaultAssertOptions) {
    const assertOptions = {
        ...fluent_api_1.defaultAssertOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        return await expectThatCssSelectorHasText(selector, expectedText, page, assertOptions);
    }
    return await expectThatSelectorObjectHasText(selector, expectedText, page, assertOptions);
}
exports.expectThatSelectorHasText = expectThatSelectorHasText;
