"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorIsChecked = exports.isChecked = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function isChecked(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.isSelectorChecked(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.isSelectorObjectChecked(selector, page, waitOptions);
        return result;
    }
}
exports.isChecked = isChecked;
async function expectThatCssSelectorIsChecked(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isChecked(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        return `Selector '${selector}' is unchecked.`;
    }, waitOptions);
}
async function expectThatSelectorObjectIsChecked(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isChecked(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        return `Selector '${selector.toString()}' is unchecked.`;
    }, waitOptions);
}
async function expectThatSelectorIsChecked(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorIsChecked(selector, page, options);
    }
    return await expectThatSelectorObjectIsChecked(selector, page, options);
}
exports.expectThatSelectorIsChecked = expectThatSelectorIsChecked;
