"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorIsDisabled = exports.isDisabled = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const playwright_fluent_1 = require("../../fluent-api/playwright-fluent");
async function isDisabled(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.isSelectorDisabled(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.isSelectorObjectDisabled(selector, page, waitOptions);
        return result;
    }
}
exports.isDisabled = isDisabled;
async function expectThatCssSelectorIsDisabled(selector, page, options = playwright_fluent_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...playwright_fluent_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isDisabled(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        return `Selector '${selector}' is enabled.`;
    }, waitOptions);
}
async function expectThatSelectorObjectIsDisabled(selector, page, options = playwright_fluent_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...playwright_fluent_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isDisabled(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        return `Selector '${selector.toString()}' is enabled.`;
    }, waitOptions);
}
async function expectThatSelectorIsDisabled(selector, page, options = playwright_fluent_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorIsDisabled(selector, page, options);
    }
    return await expectThatSelectorObjectIsDisabled(selector, page, options);
}
exports.expectThatSelectorIsDisabled = expectThatSelectorIsDisabled;
