"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorIsNotVisibleInViewport = exports.isNotVisibleInViewport = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function isNotVisibleInViewport(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.isSelectorNotVisibleInViewport(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.isSelectorObjectNotVisibleInViewport(selector, page, waitOptions);
        return result;
    }
}
exports.isNotVisibleInViewport = isNotVisibleInViewport;
async function expectThatCssSelectorIsNotVisibleInViewport(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isNotVisibleInViewport(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector}' is visible in the current viewport.`, waitOptions);
}
async function expectThatSelectorObjectIsNotVisibleInViewport(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isNotVisibleInViewport(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector.toString()}' is visible in the current viewport.`, waitOptions);
}
async function expectThatSelectorIsNotVisibleInViewport(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorIsNotVisibleInViewport(selector, page, options);
    }
    return await expectThatSelectorObjectIsNotVisibleInViewport(selector, page, options);
}
exports.expectThatSelectorIsNotVisibleInViewport = expectThatSelectorIsNotVisibleInViewport;
