"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorIsNotVisible = exports.isNotVisible = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function isNotVisible(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.isSelectorNotVisible(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.isSelectorObjectNotVisible(selector, page, waitOptions);
        return result;
    }
}
exports.isNotVisible = isNotVisible;
async function expectThatCssSelectorIsNotVisible(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isNotVisible(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector}' is visible.`, waitOptions);
}
async function expectThatSelectorObjectIsNotVisible(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isNotVisible(selector, page, utils_1.noWaitNoThrowOptions), `Selector '${selector.toString()}' is visible.`, waitOptions);
}
async function expectThatSelectorIsNotVisible(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorIsNotVisible(selector, page, options);
    }
    return await expectThatSelectorObjectIsNotVisible(selector, page, options);
}
exports.expectThatSelectorIsNotVisible = expectThatSelectorIsNotVisible;
