"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorIsReadOnly = exports.isReadOnly = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const playwright_fluent_1 = require("../../fluent-api/playwright-fluent");
async function isReadOnly(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.isSelectorReadOnly(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.isSelectorObjectReadOnly(selector, page, waitOptions);
        return result;
    }
}
exports.isReadOnly = isReadOnly;
async function expectThatCssSelectorIsReadOnly(selector, page, options = playwright_fluent_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...playwright_fluent_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isReadOnly(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        return `Selector '${selector}' is not read-only.`;
    }, waitOptions);
}
async function expectThatSelectorObjectIsReadOnly(selector, page, options = playwright_fluent_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...playwright_fluent_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isReadOnly(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        return `Selector '${selector.toString()}' is not read-only.`;
    }, waitOptions);
}
async function expectThatSelectorIsReadOnly(selector, page, options = playwright_fluent_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorIsReadOnly(selector, page, options);
    }
    return await expectThatSelectorObjectIsReadOnly(selector, page, options);
}
exports.expectThatSelectorIsReadOnly = expectThatSelectorIsReadOnly;
