"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectThatSelectorIsUnchecked = exports.isUnchecked = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const action = tslib_1.__importStar(require("../../actions"));
const fluent_api_1 = require("../../fluent-api");
async function isUnchecked(selector, page, options = utils_1.defaultWaitUntilOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...options,
    };
    if (typeof selector === 'string') {
        const result = await action.isSelectorUnchecked(selector, page, waitOptions);
        return result;
    }
    {
        const result = await action.isSelectorObjectUnchecked(selector, page, waitOptions);
        return result;
    }
}
exports.isUnchecked = isUnchecked;
async function expectThatCssSelectorIsUnchecked(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isUnchecked(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await action.exists(selector, page);
        if (!exists) {
            return `Selector '${selector}' was not found in DOM.`;
        }
        return `Selector '${selector}' is checked.`;
    }, waitOptions);
}
async function expectThatSelectorObjectIsUnchecked(selector, page, options = fluent_api_1.defaultAssertOptions) {
    const waitOptions = {
        ...utils_1.defaultWaitUntilOptions,
        ...fluent_api_1.defaultAssertOptions,
        ...options,
        throwOnTimeout: true,
    };
    await (0, utils_1.waitUntil)(() => isUnchecked(selector, page, utils_1.noWaitNoThrowOptions), async () => {
        const exists = await selector.exists();
        if (!exists) {
            return `Selector '${selector.toString()}' was not found in DOM.`;
        }
        return `Selector '${selector.toString()}' is checked.`;
    }, waitOptions);
}
async function expectThatSelectorIsUnchecked(selector, page, options = fluent_api_1.defaultAssertOptions) {
    if (typeof selector === 'string') {
        return await expectThatCssSelectorIsUnchecked(selector, page, options);
    }
    return await expectThatSelectorObjectIsUnchecked(selector, page, options);
}
exports.expectThatSelectorIsUnchecked = expectThatSelectorIsUnchecked;
