"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const SUT = tslib_1.__importStar(require("../../playwright-fluent"));
const utils_1 = require("../../../utils");
describe('Playwright Fluent - expectThat does not exist', () => {
    let p;
    beforeEach(() => {
        p = new SUT.PlaywrightFluent();
    });
    afterEach(async () => {
        await p.close();
    });
    test('should give back an error when selector is hidden', async () => {
        // Given
        const url = `file:${path.join(__dirname, 'expect-does-not-exist.test.html')}`;
        const selector = '#hidden';
        // When
        let result = undefined;
        try {
            await p
                .withBrowser('chromium')
                .withOptions({ headless: false })
                .withCursor()
                .navigateTo(url)
                .expectThatSelector(selector)
                .doesNotExist({ timeoutInMilliseconds: 2000 });
        }
        catch (error) {
            result = error;
        }
        // Then
        expect(result && result.message).toContain("Selector '#hidden' was still found in DOM.");
    });
    test('should give back an error when selector object is hidden', async () => {
        // Given
        const url = `file:${path.join(__dirname, 'expect-does-not-exist.test.html')}`;
        const selector = p.selector('#hidden');
        // When
        let result = undefined;
        try {
            await p
                .withBrowser('chromium')
                .withOptions({ headless: false })
                .withCursor()
                .navigateTo(url)
                .expectThat(selector)
                .doesNotExist({ timeoutInMilliseconds: 2000 });
        }
        catch (error) {
            result = error;
        }
        // Then
        expect(result && result.message).toContain("Selector 'selector(#hidden)' was still found in DOM.");
    });
    test('should wait until selector is removed from dom - chromium', async () => {
        // Given
        const url = `file:${path.join(__dirname, 'expect-does-not-exist.test.html')}`;
        const selector = '#visible-then-removed';
        // When
        await p
            .withBrowser('chromium')
            .withOptions({ headless: false })
            .withCursor()
            .navigateTo(url)
            .expectThat(selector)
            .doesNotExist();
        // Then
        const exists = await p.doesNotExist(selector, utils_1.noWaitNoThrowOptions);
        expect(exists).toBe(true);
    });
    test('should wait until selector object is removed from dom - chromium', async () => {
        // Given
        const url = `file:${path.join(__dirname, 'expect-does-not-exist.test.html')}`;
        const selector = p.selector('#visible-then-removed');
        // When
        await p
            .withBrowser('chromium')
            .withOptions({ headless: false })
            .withCursor()
            .navigateTo(url)
            .expectThatSelector(selector)
            .doesNotExist();
        // Then
        const exists = await p.doesNotExist(selector, utils_1.noWaitNoThrowOptions);
        expect(exists).toBe(true);
    });
});
