"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const SUT = tslib_1.__importStar(require("../../playwright-fluent"));
describe('Playwright Fluent - runStory', () => {
    let p;
    beforeEach(() => {
        p = new SUT.PlaywrightFluent();
    });
    afterEach(async () => {
        await p.close();
    });
    test('should chain two stories - chromium', async () => {
        // Given
        const url = `file:${path.join(__dirname, 'run-story.test.html')}`;
        const selector = 'select#selectWithBlankOption';
        const startApp = async (p, props) => {
            await p
                .withBrowser(props.browser)
                .withOptions({ headless: props.isHeadless })
                .withCursor()
                .navigateTo(props.url);
        };
        const selectLabel = async (p, label) => {
            await p.select(label).in(selector);
        };
        // When
        await p
            .runStory(startApp, { browser: 'chromium', isHeadless: false, url })
            .runStory(selectLabel, 'label 2');
        // Then
        const value = await p.getValueOf(selector);
        expect(value).toBe('value 2');
    });
    test('should run embedded stories - chromium', async () => {
        // Given
        const url = `file:${path.join(__dirname, 'run-story.test.html')}`;
        const selector = 'select#selectWithBlankOption';
        const startApp = async (p, props) => {
            await p
                .withBrowser(props.browser)
                .withOptions({ headless: props.isHeadless })
                .withCursor()
                .navigateTo(props.url);
        };
        const selectLabel = async (p, label) => {
            await p.select(label).in(selector);
        };
        const mainStory = async (p) => {
            await p
                .runStory(startApp, { browser: 'chromium', isHeadless: false, url })
                .runStory(selectLabel, 'label 2');
        };
        // When
        await p.runStory(mainStory);
        // Then
        const value = await p.getValueOf(selector);
        expect(value).toBe('value 2');
    });
    test('should combine stories - chromium', async () => {
        // Given
        const results = [];
        const storyA1 = async (p) => {
            results.push('storyA1');
            await p.expectThatAsyncFunc(async () => true).resolvesTo(true);
        };
        const storyA2 = async (p) => {
            results.push('storyA2');
            await p.expectThatAsyncFunc(async () => true).resolvesTo(true);
        };
        const storyA = async (p) => {
            results.push('storyA');
            // prettier-ignore
            await p
                .runStory(storyA1)
                .and(storyA2);
        };
        const storyB1 = async (p) => {
            results.push('storyB1');
            await p.expectThatAsyncFunc(async () => true).resolvesTo(true);
        };
        const storyB2 = async (p) => {
            results.push('storyB2');
            await p.expectThatAsyncFunc(async () => true).resolvesTo(true);
        };
        const storyB = async (p) => {
            results.push('storyB');
            // prettier-ignore
            await p
                .do(storyB1)
                .and(storyB2);
        };
        const mainStory = async (p) => {
            // prettier-ignore
            await p.attemptsTo(storyA);
            await p.and(storyB);
        };
        // When
        await p.verifyIf(mainStory);
        // Then
        expect(results.join()).toBe('storyA,storyA1,storyA2,storyB,storyB1,storyB2');
    });
});
