"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const playwright_fluent_1 = require("../../playwright-fluent");
describe('Playwright Fluent - withBrowser', () => {
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    test('should target chrome', async () => {
        // Given
        const browser = 'chrome';
        const p = new playwright_fluent_1.PlaywrightFluent();
        // When
        await p.withBrowser(browser);
        // Then
        const browserInstance = p.currentBrowser();
        const pageInstance = p.currentPage();
        expect(browserInstance).toBeDefined();
        expect(pageInstance).toBeDefined();
        const userAgent = pageInstance && (await pageInstance.evaluate(() => window.navigator.userAgent));
        expect(userAgent).toContain('HeadlessChrome');
        browserInstance && (await browserInstance.close());
    });
    test('should target chromium', async () => {
        // Given
        const browser = 'chromium';
        const p = new playwright_fluent_1.PlaywrightFluent();
        // When
        await p.withBrowser(browser);
        // Then
        const browserInstance = p.currentBrowser();
        const pageInstance = p.currentPage();
        expect(browserInstance).toBeDefined();
        expect(pageInstance).toBeDefined();
        const userAgent = pageInstance && (await pageInstance.evaluate(() => window.navigator.userAgent));
        expect(userAgent).toContain('HeadlessChrome');
        browserInstance && (await browserInstance.close());
    });
    test('should target msedge', async () => {
        // Given
        const browser = 'msedge';
        const p = new playwright_fluent_1.PlaywrightFluent();
        // When
        await p.withBrowser(browser);
        // Then
        const browserInstance = p.currentBrowser();
        const pageInstance = p.currentPage();
        expect(browserInstance).toBeDefined();
        expect(pageInstance).toBeDefined();
        const userAgent = pageInstance && (await pageInstance.evaluate(() => window.navigator.userAgent));
        expect(userAgent).toContain('Edg/');
        browserInstance && (await browserInstance.close());
    });
    test('should target firefox', async () => {
        // Given
        const browser = 'firefox';
        const p = new playwright_fluent_1.PlaywrightFluent();
        // When
        await p.withBrowser(browser);
        // Then
        const browserInstance = p.currentBrowser();
        const pageInstance = p.currentPage();
        expect(browserInstance).toBeDefined();
        expect(pageInstance).toBeDefined();
        const userAgent = pageInstance && (await pageInstance.evaluate(() => window.navigator.userAgent));
        expect(userAgent).toContain('Firefox');
        browserInstance && (await browserInstance.close());
    });
    test('should target webkit', async () => {
        // Given
        const browser = 'webkit';
        const p = new playwright_fluent_1.PlaywrightFluent();
        // When
        await p.withBrowser(browser);
        // Then
        const browserInstance = p.currentBrowser();
        const pageInstance = p.currentPage();
        expect(browserInstance).toBeDefined();
        expect(pageInstance).toBeDefined();
        const userAgent = pageInstance && (await pageInstance.evaluate(() => window.navigator.userAgent));
        expect(userAgent).toContain('Safari');
        browserInstance && (await browserInstance.close());
    });
    test('should throw an error on unknown browser', async () => {
        // Given
        const browser = 'yo';
        const p = new playwright_fluent_1.PlaywrightFluent();
        // When
        let result = undefined;
        try {
            await p.withBrowser(browser);
        }
        catch (error) {
            result = error;
        }
        // Then
        const expectedErrorMessage = "Browser named 'yo' is unknown. It should be one of 'chrome', 'chromium', 'chrome-canary', 'firefox', 'webkit'";
        expect(result && result.message).toContain(expectedErrorMessage);
        expect((p.lastError() || {}).message).toBe(expectedErrorMessage);
    });
});
