"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const SUT = tslib_1.__importStar(require("../../playwright-fluent"));
describe('Playwright Fluent - withTracing()', () => {
    let p;
    beforeEach(() => {
        p = new SUT.PlaywrightFluent();
    });
    afterEach(async () => {
        await p.close();
    });
    test('should return an error when startTracing() is called before withTracing()', async () => {
        // Given
        const browser = 'chromium';
        const url = 'https://reactstrap.github.io';
        const tracePath = path_1.default.join(__dirname, 'trace1.chromium.zip');
        // When
        let result = undefined;
        try {
            // prettier-ignore
            await p
                .withBrowser(browser)
                .withOptions({ headless: false })
                //.withTracing()
                .startTracing({ title: 'my first trace' })
                .navigateTo(url)
                .stopTracingAndSaveTrace({ path: tracePath });
        }
        catch (error) {
            result = error;
        }
        // Then
        expect(result && result.message).toContain('Cannot start Tracing because Tracing is not enabled. Maybe you forgot to call the withTrace(options)');
    });
    test('should return an error when stopTracing() is called before withTracing()', async () => {
        // Given
        const browser = 'chromium';
        const url = 'https://reactstrap.github.io';
        const tracePath = path_1.default.join(__dirname, 'trace1.chromium.zip');
        // When
        let result = undefined;
        try {
            // prettier-ignore
            await p
                .withBrowser(browser)
                .withOptions({ headless: false })
                //.withTracing()
                //.startTracing({ title: 'my first trace' })
                .navigateTo(url)
                .stopTracingAndSaveTrace({ path: tracePath });
        }
        catch (error) {
            result = error;
        }
        // Then
        expect(result && result.message).toContain('Cannot stop Tracing and save trace file because Tracing is not enabled. Maybe you forgot to call the withTrace(options)');
    });
});
