"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const SUT = tslib_1.__importStar(require("./index"));
describe('filename generator', () => {
    test('should generate uniqe filenames when no options', async () => {
        // Given
        const filenames = new Set();
        const count = 100;
        // When
        for (let index = 1; index <= count; index++) {
            filenames.add(SUT.uniqueFilename());
        }
        // Then
        expect(filenames.size).toBe(100);
    });
    test('should generate uniqe filenames with prefix', async () => {
        // Given
        const filenames = new Set();
        const count = 100;
        const prefix = 'har-';
        // When
        for (let index = 1; index <= count; index++) {
            filenames.add(SUT.uniqueFilename({ prefix }));
        }
        // Then
        expect(filenames.size).toBe(100);
        filenames.forEach((filename) => {
            expect(filename.startsWith(prefix)).toBe(true);
            expect(filename.endsWith('.json')).toBe(true);
        });
    });
    test('should generate uniqe filenames with prefix and extension', async () => {
        // Given
        const filenames = new Set();
        const count = 100;
        const prefix = 'har-';
        const extension = '.foobar';
        // When
        for (let index = 1; index <= count; index++) {
            filenames.add(SUT.uniqueFilename({ prefix, extension }));
        }
        // Then
        expect(filenames.size).toBe(100);
        filenames.forEach((filename) => {
            expect(filename.startsWith(prefix)).toBe(true);
            expect(filename.endsWith(extension)).toBe(true);
        });
    });
});
